@@ -32,7 +32,7 @@
 
 /*--------------------------------------------------------------------*/
 
-static char *version = "MACVT -- Algol 60 Converter, Version 2.0";
+static char *version = "MACVT -- Algol 60 Converter, Version 2.1";
 /* Version information. */
 
 static char *infilename = "";
@@ -156,8 +156,7 @@ static void my_assert(char *expr, char *file, int line)
 {     fprintf(stderr,
          "Internal converter error: %s, file %s, line %d\n",
          expr, file, line);
-      fprintf(stderr,
-         "Please, report to Andrew Makhorin <mao@mai2.rcnet.ru>\n");
+      fprintf(stderr, "Please, report to <bug-marst@gnu.org>\n");
       fflush(stderr);
       fflush(outfile);
       exit(EXIT_FAILURE);
@@ -234,7 +233,8 @@ static void scan_pad(int flag)
 -- until semicolon (these characters are sent to output text file). */
 
 static void scan_comment(void)
-{     for (;;)
+{     if (isalnum(ch)) emit_sym(S_CHAR, ' ');
+      for (;;)
       {  if (ch == 0x1A) break; /* terminated by eof */
          if (ch == ';') break;
          if (old_sc && ch == '.')
@@ -990,7 +990,7 @@ static void process_cmdline(int argc, char *argv[])
             display_help(argv[0]);
          else if (strcmp(argv[k], "-i") == 0 ||
                   strcmp(argv[k], "--ignore-case") == 0)
-            ignore_case = 0;
+            ignore_case = 1;
          else if (strcmp(argv[k], "-m") == 0 ||
                   strcmp(argv[k], "--more-free") == 0)
             free_coding = 1, more_free = 1;
